<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar_EG">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Select one or more devices</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Select one or more devices</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Remove window frame</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Flip vertical</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Flip horizontal</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Black-and-white</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Switch to Window</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Switch to Fullscreen</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>الكاميرا</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>The setup was successful.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Close this window and start vokoscreenNG again.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Have fun with vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>الحوار</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>No filemanager found.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Please install a filemanager.</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>No filemanager found.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Please install a filemanager.</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>تحذير</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>تحذير لاتوجد مساحة كافية عليك حذف بعض الاشياء ليتم التسجيل.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>The free disk space limit is reached.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limit of free disk space</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>The recording was stopped, not enough free disk space.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>No filemanager found.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Please install a filemanager.</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Sourcecode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Translations</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donate</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Sourcecode</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Homepage</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Translations</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donate</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>No filemanager found.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Please install a filemanager.</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Select one or more devices</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Select one or more devices</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>No filemanager found.</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Please install a filemanager.</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continue</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Magnification</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continue</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Magnification</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Select one or more devices</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Flip horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Flip vertical</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Black-and-white</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remove window frame</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Camera settings</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Magnification</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Video size:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Free disk space:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Record Time:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Do not record mouse cursor</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Hour</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minute</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Start the timer</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Stop recording after</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Hours</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minutes</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Seconds</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopath</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Limit of free disk space</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Show in systray</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Second wait before recording</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Look for updates</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Help</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Available</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Not available</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continue</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Play last record</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Open folder</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimized when recording starts</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Starts minimized</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Flip horizontal</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Flip vertical</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Black-and-white</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remove window frame</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Reset all settings at the next start</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright and license from pictures</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabyte</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Screencast</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Player</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automatically</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Create images of tabs </translation>
    </message>
    <message>
        <source>License information</source>
        <translation>License information</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>OFF</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Global keyboard shortcuts</translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Assigned shortcut keys.</translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Keyboard shortcut not assigned or assigned more than once.</translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>If it shows assigned but does not work, it is being used by another program.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Snapshot</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Imagepath</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Hide this window</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Seconds wait before recording</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Window</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright and license from pictures</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Create images of tabs </translation>
    </message>
    <message>
        <source>License information</source>
        <translation>License information</translation>
    </message>
    <message>
        <source>ON</source>
        <translation>ON</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>OFF</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Record Time:</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Video size:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Free disk space:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Window</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Fullscreen</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videocodec</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Frames</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Available</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Not available</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Do not record mouse cursor</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiocodec</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Videopath</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Countdown</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>مساعدة</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Invert</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gray</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Black-and-white</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Camera</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Flip vertical</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Flip horizontal</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Remove window frame</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Second wait before recording</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Reset</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Hide this window</translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Seconds wait before recording</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Copyright and license from pictures</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Play</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
</context>
</TS>